@@ -35,8 +35,13 @@
 #include <linux/irda.h>
 #endif
 
+#include <arpa/inet.h>
+#ifdef HAVE_ARPA_NAMESER_H
 #include <arpa/nameser.h>
+#endif
+#ifdef HAVE_RESOLV_H
 #include <resolv.h>
+#endif
 
 #if !defined (NI_MAXSERV) || !defined (NI_MAXHOST)
 #  include <netdb.h>
@@ -51,4 +56,15 @@
 #  define NI_MAXSERV 64
 #endif
 
+#if !defined (INADDR_NONE)
+#  define INADDR_NONE (-1)
+#endif
+
+#if !defined (UNIX_PATH_MAX)
+/* UNP: 14.2 - Posix.1g at least 100 bytes */
+#  define LINC_UNIX_PATH_MAX 100
+#else
+#  define LINC_UNIX_PATH_MAX UNIX_PATH_MAX
+#endif
+
 #endif /* LINC_HACKS_H */
